Description Usage Arguments Value
View source: R/process_coc_shapefiles.R
Creates a regular expression used to filter shapefile in input_data
1 | build_regex(file_extensions = c("gdb", "shp"))
|
file_extensions |
A character vector of shapefile file extensions to include in the regular expression. |
A character vector containing the regular expression.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.