Description Usage Arguments Value See Also
View source: R/coc_economic_indicators.R
Grabs the chosen month's or annual average unemployment rate and parses the county FIPS code.
1 | process_unemployment(unemployment_data, use_month = "M01")
|
unemployment_data |
A data frame with raw unemployment data from
|
use_month |
A character value with the month to use or the annual average. For annual average use "M13". Defaults to January ("M01"). |
A data frame:
county_fips: County FIPS code
year: Year
unemployment_rate: Unemployment rate
build_coc_unemployment() for the main function
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.