Description Usage Arguments Value
Flexibly writes the combined data set to disk. Since the actual call to the
function that will write the dataset is built dynamically, it can support
many filetypes as long as they are of the form output_function(data, file_path.
1 2 3 4 5 6 7 | write_dataset(
data,
output_function,
extension,
output_dir = "output_data",
file_name = "coc_data"
)
|
data |
A data frame with the combined dataset. |
output_function |
A character string with the function that will actually write the file. |
extension |
A character string with the extension for the output file. |
output_dir |
A character string with the path to the output directory. |
file_name |
A character string with the file name. |
Invisibly returns a character string with the output file's path.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.